# Yahel

**Yahel** é um pacote Python para cientistas e analistas de dados, permitindo criar visualizações como:
- Mapas de Calor
- Gráficos de Pizza
- Gráficos de Área

## Instalação

Instale via pip:
```bash
pip install yahel

